@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use JSON;
 use Carp;
@@ -13,21 +13,25 @@ use Pandoc::Walker;
 use Pandoc::Elements ();
 
 use parent 'Exporter';
-our @EXPORT = qw(pandoc_filter stringify);
+our @EXPORT = qw(pandoc_filter pandoc_walk stringify);
 
 sub stringify {
     join '', @{
         $_[0]->query({ 
-            'Str|Code|Math'   => sub { $_[0]->content },
+            'Str|Code|Math'   => sub { $_->content },
             'LineBreak|Space' => sub { ' ' },
         });
     };
 }
 
-sub pandoc_filter(@) { ## no critic
+sub pandoc_walk(@) { ## no critic
     my $filter = Pandoc::Filter->new(@_);
     my $ast = Pandoc::Elements::pandoc_json(<STDIN>);
     $filter->apply($ast);
+}
+
+sub pandoc_filter(@) { ## no critic
+    my $ast = pandoc_walk(@_);
     my $json = JSON->new->utf8->allow_blessed->convert_blessed->encode($ast);
     #my $json = $ast->to_json; # TODO
     say STDOUT $json;
@@ -45,7 +49,8 @@ sub new {
             my $action = $_[$i+1];
             push @actions, sub {
                 return unless List::Util::first { $_[0]->name eq $_ } @names;
-                $action->(@_);
+                $_=$_[0];
+                $action->($_);
             };
         }
         bless \@actions, $class;
@@ -86,8 +91,8 @@ documentation|http://johnmacfarlane.net/pandoc/scripting.html> converts level
     use Pandoc::Elements;
 
     pandoc_filter Header => sub {
-        return unless $_[0]->level >= 2;
-        return Para [ Emph $_[0]->content ];
+        return unless $_->level >= 2;
+        return Para [ Emph $_->content ];
     };
 
 To apply this filter on a Markdown file:
@@ -117,8 +122,11 @@ of this module.
 Create a new filter with one or more action functions, given as code
 reference(s). Each function is expected to return an element, an empty array
 reference, or C<undef> to modify, remove, or keep a traversed element in the
-AST. If actions are given as hash, key values are used to check which elements
-to apply for, e.g. 
+AST. The current element is passed to an action function both as first argument
+and in the special variable C<$_>. 
+
+If actions are given as hash, key values are used to check which elements to
+apply for, e.g. 
 
     Pandoc::Filter->new( 
         Header                 => sub { ... }, 
@@ -145,11 +153,20 @@ AST as single line of JSON. This function is roughly equivalent to
     Pandoc::Filter->new(@actions)->apply($ast);
     say $ast->to_json;
 
+=head2 pandoc_walk( @actions | %actions )
+
+Read a single line of JSON from STDIN and walk down the AST.
+
 =head2 stringify( $ast )
 
 Walks the ast and returns concatenated string content, leaving out all
 formatting.
 
+=head1 SEE ALSO
+
+Script L<pandoc-walk> installed with this module facilitates execution of
+C<pandoc_walk> to traverse a document.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2014- Jakob Voß
